# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/litum',
                'doc_host': 'https://dsm-72.github.io',
                'git_url': 'https://github.com/dsm-72/litum',
                'lib_path': 'litum'},
  'syms': { 'litum.decs': { 'litum.decs.set_attr': ('decs.html#set_attr', 'litum/decs.py'),
                            'litum.decs.set_default': ('decs.html#set_default', 'litum/decs.py'),
                            'litum.decs.set_dtype': ('decs.html#set_dtype', 'litum/decs.py'),
                            'litum.decs.set_fallback': ('decs.html#set_fallback', 'litum/decs.py'),
                            'litum.decs.set_method': ('decs.html#set_method', 'litum/decs.py'),
                            'litum.decs.set_repr': ('decs.html#set_repr', 'litum/decs.py')},
            'litum.enum': { 'litum.enum.BaseTypedEnum': ('enum.html#basetypedenum', 'litum/enum.py'),
                            'litum.enum.LitIntEnum': ('enum.html#litintenum', 'litum/enum.py'),
                            'litum.enum.LitStrEnum': ('enum.html#litstrenum', 'litum/enum.py'),
                            'litum.enum.LiteralEnum': ('enum.html#literalenum', 'litum/enum.py'),
                            'litum.enum.OperatorEnum': ('enum.html#operatorenum', 'litum/enum.py'),
                            'litum.enum.OperatorEnum.__call__': ('enum.html#operatorenum.__call__', 'litum/enum.py'),
                            'litum.enum.TypedFallbackMixin': ('enum.html#typedfallbackmixin', 'litum/enum.py'),
                            'litum.enum.TypedFallbackMixin._missing_': ('enum.html#typedfallbackmixin._missing_', 'litum/enum.py'),
                            'litum.enum.TypedFallbackMixin.check_dtype': ('enum.html#typedfallbackmixin.check_dtype', 'litum/enum.py'),
                            'litum.enum.TypedFallbackMixin.check_fallback': ( 'enum.html#typedfallbackmixin.check_fallback',
                                                                              'litum/enum.py'),
                            'litum.enum.TypedFallbackMixin.match_val_to_member': ( 'enum.html#typedfallbackmixin.match_val_to_member',
                                                                                   'litum/enum.py'),
                            'litum.enum.TypedFallbackMixin.val_is_member_name': ( 'enum.html#typedfallbackmixin.val_is_member_name',
                                                                                  'litum/enum.py'),
                            'litum.enum.TypedFallbackMixin.val_is_member_value': ( 'enum.html#typedfallbackmixin.val_is_member_value',
                                                                                   'litum/enum.py'),
                            'litum.enum.TypedFallbackMixin.val_matches_member': ( 'enum.html#typedfallbackmixin.val_matches_member',
                                                                                  'litum/enum.py')},
            'litum.meta': { 'litum.meta.DataTypedEnumMeta': ('meta.html#datatypedenummeta', 'litum/meta.py'),
                            'litum.meta.FallbackEnumMeta': ('meta.html#fallbackenummeta', 'litum/meta.py'),
                            'litum.meta.TypedEnumMeta': ('meta.html#typedenummeta', 'litum/meta.py'),
                            'litum.meta.TypedEnumMeta.__init__': ('meta.html#typedenummeta.__init__', 'litum/meta.py'),
                            'litum.meta.TypedEnumMeta.__new__': ('meta.html#typedenummeta.__new__', 'litum/meta.py'),
                            'litum.meta.TypedEnumMeta.__prepare__': ('meta.html#typedenummeta.__prepare__', 'litum/meta.py'),
                            'litum.meta.TypedEnumMeta.clsname': ('meta.html#typedenummeta.clsname', 'litum/meta.py'),
                            'litum.meta.TypedEnumMeta.has_fbmem': ('meta.html#typedenummeta.has_fbmem', 'litum/meta.py'),
                            'litum.meta.TypedEnumMeta.items': ('meta.html#typedenummeta.items', 'litum/meta.py'),
                            'litum.meta.TypedEnumMeta.members': ('meta.html#typedenummeta.members', 'litum/meta.py'),
                            'litum.meta.TypedEnumMeta.memdict': ('meta.html#typedenummeta.memdict', 'litum/meta.py'),
                            'litum.meta.TypedEnumMeta.tuples': ('meta.html#typedenummeta.tuples', 'litum/meta.py'),
                            'litum.meta.TypedEnumMeta.values': ('meta.html#typedenummeta.values', 'litum/meta.py')}}}
